@@ -1,7 +1,7 @@
 /*
- * /src/NTP/ntp4-dev/libparse/clk_meinberg.c,v 4.12 2005/04/16 17:32:10 kardel RELEASE_20050508_A
+ * /src/NTP/REPOSITORY/ntp4-dev/libparse/clk_meinberg.c,v 4.12.2.1 2005/09/25 10:22:35 kardel RELEASE_20050925_A
  *  
- * clk_meinberg.c,v 4.12 2005/04/16 17:32:10 kardel RELEASE_20050508_A
+ * clk_meinberg.c,v 4.12.2.1 2005/09/25 10:22:35 kardel RELEASE_20050925_A
  *
  * Meinberg clock support
  *
@@ -157,7 +157,7 @@ mbg_csum(
 	 )
 {
   unsigned long sum = 0;
-  short i;
+  unsigned int i;
   
   for ( i = 0; i < n; i++ )
     sum += *p++;
@@ -209,10 +209,10 @@ static struct format meinberg_fmt[] =
 	}
 };
 
-static u_long cvt_meinberg P((unsigned char *, int, struct format *, clocktime_t *, void *));
-static u_long cvt_mgps     P((unsigned char *, int, struct format *, clocktime_t *, void *));
-static u_long mbg_input    P((parse_t *, unsigned int, timestamp_t *));
-static u_long gps_input    P((parse_t *, unsigned int, timestamp_t *));
+static u_long cvt_meinberg (unsigned char *, int, struct format *, clocktime_t *, void *);
+static u_long cvt_mgps     (unsigned char *, int, struct format *, clocktime_t *, void *);
+static u_long mbg_input    (parse_t *, unsigned int, timestamp_t *);
+static u_long gps_input    (parse_t *, unsigned int, timestamp_t *);
 
 struct msg_buf
 {
@@ -646,7 +646,7 @@ gps_input(
       msg_buf->phase = MBG_NONE; /* buffer overflow - discard */
       parseio->parse_data[parseio->parse_index] = '\0';
       memcpy(parseio->parse_ldata, parseio->parse_data, (unsigned)(parseio->parse_index+1));
-      parseio->parse_ldsize = parseio->parse_index+1;
+      parseio->parse_ldsize = parseio->parse_index;
       return PARSE_INP_DATA;
     }
   
@@ -670,7 +670,7 @@ gps_input(
 	  parseprintf(DD_PARSE, ("gps_input: string complete\n"));
 	  parseio->parse_data[parseio->parse_index] = '\0';
 	  memcpy(parseio->parse_ldata, parseio->parse_data, (unsigned)(parseio->parse_index+1));
-	  parseio->parse_ldsize = parseio->parse_index+1;
+	  parseio->parse_ldsize = parseio->parse_index;
 	  parseio->parse_index = 0;
 	  return PARSE_INP_TIME;
 	}
@@ -735,6 +735,9 @@ int clk_meinberg_bs;
  * History:
  *
  * clk_meinberg.c,v
+ * Revision 4.12.2.1  2005/09/25 10:22:35  kardel
+ * cleanup buffer bounds
+ *
  * Revision 4.12  2005/04/16 17:32:10  kardel
  * update copyright
  *
